Asynchronous library for retrieving IP address information
For retrieval of a single address, simply use get_ip and set
appropriate parameters.
In case a finer-grained control over the source of addresses is required,
individual Providers on which get_ip is based can be found in gip
(for global) and hostip (for local).
Module libc_getips contains a low-level function to receive all addresses
directly from the interfaces/adapters.
Modules
Implementations of Provider that receive global IP addresses from online services.
This is an asynchronous rewrite of dalance/gip.
Implementations of Provider that receive local IP addresses of the machine
from libc APIs and command-line helper programs (if available).
Receive IP addresses of NICs with libc APIs.
Enums
Error type of IP retrieval methods.
Scope of the IP to be received.
Type of global address.
Traits
Any IP Provider.
Functions
Receive a IP address of family ip_type that has a scope of ip_scope on an interface named nic.
Type Definitions
A Result alias where the Err variant is getip::Error.